==> gr-gsm-fr-vocoder-0.1.tar.gz: gr-gsm-fr-vocoder-0.1/src/lib/gsm_full_rate.py <==
# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _gsm_full_rate

def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name) or (name == "thisown"):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


class gsm_fr_encode_sp_sptr(_object):
    """Proxy of C++ gsm_fr_encode_sp_sptr class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, gsm_fr_encode_sp_sptr, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, gsm_fr_encode_sp_sptr, name)
    def __repr__(self):
        return "<%s.%s; proxy of C++ boost::shared_ptr<gsm_fr_encode_sp > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    def __init__(self, *args):
        """
        __init__(self) -> gsm_fr_encode_sp_sptr
        __init__(self,  p) -> gsm_fr_encode_sp_sptr
        """
        _swig_setattr(self, gsm_fr_encode_sp_sptr, 'this', _gsm_full_rate.new_gsm_fr_encode_sp_sptr(*args))
        _swig_setattr(self, gsm_fr_encode_sp_sptr, 'thisown', 1)
    def __deref__(*args): 
        """__deref__(self)"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr___deref__(*args)

    def name(*args): 
        """name(self) -> string"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_name(*args)

    def input_signature(*args): 
        """input_signature(self) -> gr_io_signature_sptr"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_input_signature(*args)

    def output_signature(*args): 
        """output_signature(self) -> gr_io_signature_sptr"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_output_signature(*args)

    def unique_id(*args): 
        """unique_id(self) -> long"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_unique_id(*args)

    def output_multiple(*args): 
        """output_multiple(self) -> int"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_output_multiple(*args)

    def relative_rate(*args): 
        """relative_rate(self) -> double"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_relative_rate(*args)

    def check_topology(*args): 
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_check_topology(*args)

    def detail(*args): 
        """detail(self) -> gr_block_detail_sptr"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_detail(*args)

    def set_detail(*args): 
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_set_detail(*args)

    def __del__(self, destroy=_gsm_full_rate.delete_gsm_fr_encode_sp_sptr):
        """__del__(self)"""
        try:
            if self.thisown: destroy(self)
        except: pass


class gsm_fr_encode_sp_sptrPtr(gsm_fr_encode_sp_sptr):
    def __init__(self, this):
        _swig_setattr(self, gsm_fr_encode_sp_sptr, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, gsm_fr_encode_sp_sptr, 'thisown', 0)
        _swig_setattr(self, gsm_fr_encode_sp_sptr,self.__class__,gsm_fr_encode_sp_sptr)
_gsm_full_rate.gsm_fr_encode_sp_sptr_swigregister(gsm_fr_encode_sp_sptrPtr)


def gsm_fr_encode_sp_block(*args):
    """gsm_fr_encode_sp_block(gsm_fr_encode_sp_sptr r) -> gr_block_sptr"""
    return _gsm_full_rate.gsm_fr_encode_sp_block(*args)
gsm_fr_encode_sp_sptr.block = lambda self: gsm_fr_encode_sp_block (self)
gsm_fr_encode_sp_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


def encode_sp(*args):
    """encode_sp() -> gsm_fr_encode_sp_sptr"""
    return _gsm_full_rate.encode_sp(*args)
class gsm_fr_decode_ps_sptr(_object):
    """Proxy of C++ gsm_fr_decode_ps_sptr class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, gsm_fr_decode_ps_sptr, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, gsm_fr_decode_ps_sptr, name)
    def __repr__(self):
        return "<%s.%s; proxy of C++ boost::shared_ptr<gsm_fr_decode_ps > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    def __init__(self, *args):
        """
        __init__(self) -> gsm_fr_decode_ps_sptr
        __init__(self,  p) -> gsm_fr_decode_ps_sptr
        """
        _swig_setattr(self, gsm_fr_decode_ps_sptr, 'this', _gsm_full_rate.new_gsm_fr_decode_ps_sptr(*args))
        _swig_setattr(self, gsm_fr_decode_ps_sptr, 'thisown', 1)
    def __deref__(*args): 
        """__deref__(self)"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr___deref__(*args)

    def name(*args): 
        """name(self) -> string"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_name(*args)

    def input_signature(*args): 
        """input_signature(self) -> gr_io_signature_sptr"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_input_signature(*args)

    def output_signature(*args): 
        """output_signature(self) -> gr_io_signature_sptr"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_output_signature(*args)

    def unique_id(*args): 
        """unique_id(self) -> long"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_unique_id(*args)

    def output_multiple(*args): 
        """output_multiple(self) -> int"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_output_multiple(*args)

    def relative_rate(*args): 
        """relative_rate(self) -> double"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_relative_rate(*args)

    def check_topology(*args): 
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_check_topology(*args)

    def detail(*args): 
        """detail(self) -> gr_block_detail_sptr"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_detail(*args)

    def set_detail(*args): 
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_set_detail(*args)

    def __del__(self, destroy=_gsm_full_rate.delete_gsm_fr_decode_ps_sptr):
        """__del__(self)"""
        try:
            if self.thisown: destroy(self)
        except: pass


class gsm_fr_decode_ps_sptrPtr(gsm_fr_decode_ps_sptr):
    def __init__(self, this):
        _swig_setattr(self, gsm_fr_decode_ps_sptr, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, gsm_fr_decode_ps_sptr, 'thisown', 0)
        _swig_setattr(self, gsm_fr_decode_ps_sptr,self.__class__,gsm_fr_decode_ps_sptr)
_gsm_full_rate.gsm_fr_decode_ps_sptr_swigregister(gsm_fr_decode_ps_sptrPtr)


def gsm_fr_decode_ps_block(*args):
    """gsm_fr_decode_ps_block(gsm_fr_decode_ps_sptr r) -> gr_block_sptr"""
    return _gsm_full_rate.gsm_fr_decode_ps_block(*args)
gsm_fr_decode_ps_sptr.block = lambda self: gsm_fr_decode_ps_block (self)
gsm_fr_decode_ps_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


def decode_ps(*args):
    """decode_ps() -> gsm_fr_decode_ps_sptr"""
    return _gsm_full_rate.decode_ps(*args)

==> gr-gsm-fr-vocoder-0.2.tar.gz: gr-gsm-fr-vocoder-0.2/src/lib/gsm_full_rate.py <==
# This file was created automatically by SWIG 1.3.27.
# Don't modify this file, modify the SWIG interface instead.

import _gsm_full_rate

def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name) or (name == "thisown"):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


def _swig_setattr_nondynamic_method(set):
    def set_attr(self,name,value):
        if hasattr(self,name) or (name in ("this", "thisown")):
            set(self,name,value)
        else:
            raise AttributeError("You cannot add attributes to %s" % self)
    return set_attr


class gsm_fr_encode_sp_sptr(object):
    """Proxy of C++ gsm_fr_encode_sp_sptr class"""
    def __repr__(self):
        return "<%s.%s; proxy of C++ boost::shared_ptr<gsm_fr_encode_sp > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    def __init__(self, *args):
        """
        __init__(self) -> gsm_fr_encode_sp_sptr
        __init__(self,  p) -> gsm_fr_encode_sp_sptr
        """
        newobj = _gsm_full_rate.new_gsm_fr_encode_sp_sptr(*args)
        self.this = newobj.this
        self.thisown = 1
        del newobj.thisown
    def __deref__(*args):
        """__deref__(self)"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr___deref__(*args)

    def name(*args):
        """name(self) -> string"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_name(*args)

    def input_signature(*args):
        """input_signature(self) -> gr_io_signature_sptr"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_input_signature(*args)

    def output_signature(*args):
        """output_signature(self) -> gr_io_signature_sptr"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_output_signature(*args)

    def unique_id(*args):
        """unique_id(self) -> long"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_unique_id(*args)

    def history(*args):
        """history(self) -> unsigned int"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_history(*args)

    def output_multiple(*args):
        """output_multiple(self) -> int"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_output_multiple(*args)

    def relative_rate(*args):
        """relative_rate(self) -> double"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_relative_rate(*args)

    def check_topology(*args):
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_check_topology(*args)

    def start(*args):
        """start(self) -> bool"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_start(*args)

    def stop(*args):
        """stop(self) -> bool"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_stop(*args)

    def detail(*args):
        """detail(self) -> gr_block_detail_sptr"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_detail(*args)

    def set_detail(*args):
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _gsm_full_rate.gsm_fr_encode_sp_sptr_set_detail(*args)

    def __del__(self, destroy=_gsm_full_rate.delete_gsm_fr_encode_sp_sptr):
        """__del__(self)"""
        try:
            if self.thisown: destroy(self)
        except: pass


class gsm_fr_encode_sp_sptrPtr(gsm_fr_encode_sp_sptr):
    def __init__(self, this):
        self.this = this
        if not hasattr(self,"thisown"): self.thisown = 0
        self.__class__ = gsm_fr_encode_sp_sptr
_gsm_full_rate.gsm_fr_encode_sp_sptr_swigregister(gsm_fr_encode_sp_sptrPtr)


def gsm_fr_encode_sp_block(*args):
    """gsm_fr_encode_sp_block(gsm_fr_encode_sp_sptr r) -> gr_block_sptr"""
    return _gsm_full_rate.gsm_fr_encode_sp_block(*args)
gsm_fr_encode_sp_sptr.block = lambda self: gsm_fr_encode_sp_block (self)
gsm_fr_encode_sp_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


def encode_sp(*args):
    """encode_sp() -> gsm_fr_encode_sp_sptr"""
    return _gsm_full_rate.encode_sp(*args)
class gsm_fr_decode_ps_sptr(object):
    """Proxy of C++ gsm_fr_decode_ps_sptr class"""
    def __repr__(self):
        return "<%s.%s; proxy of C++ boost::shared_ptr<gsm_fr_decode_ps > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    def __init__(self, *args):
        """
        __init__(self) -> gsm_fr_decode_ps_sptr
        __init__(self,  p) -> gsm_fr_decode_ps_sptr
        """
        newobj = _gsm_full_rate.new_gsm_fr_decode_ps_sptr(*args)
        self.this = newobj.this
        self.thisown = 1
        del newobj.thisown
    def __deref__(*args):
        """__deref__(self)"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr___deref__(*args)

    def name(*args):
        """name(self) -> string"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_name(*args)

    def input_signature(*args):
        """input_signature(self) -> gr_io_signature_sptr"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_input_signature(*args)

    def output_signature(*args):
        """output_signature(self) -> gr_io_signature_sptr"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_output_signature(*args)

    def unique_id(*args):
        """unique_id(self) -> long"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_unique_id(*args)

    def history(*args):
        """history(self) -> unsigned int"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_history(*args)

    def output_multiple(*args):
        """output_multiple(self) -> int"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_output_multiple(*args)

    def relative_rate(*args):
        """relative_rate(self) -> double"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_relative_rate(*args)

    def check_topology(*args):
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_check_topology(*args)

    def start(*args):
        """start(self) -> bool"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_start(*args)

    def stop(*args):
        """stop(self) -> bool"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_stop(*args)

    def detail(*args):
        """detail(self) -> gr_block_detail_sptr"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_detail(*args)

    def set_detail(*args):
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _gsm_full_rate.gsm_fr_decode_ps_sptr_set_detail(*args)

    def __del__(self, destroy=_gsm_full_rate.delete_gsm_fr_decode_ps_sptr):
        """__del__(self)"""
        try:
            if self.thisown: destroy(self)
        except: pass


class gsm_fr_decode_ps_sptrPtr(gsm_fr_decode_ps_sptr):
    def __init__(self, this):
        self.this = this
        if not hasattr(self,"thisown"): self.thisown = 0
        self.__class__ = gsm_fr_decode_ps_sptr
_gsm_full_rate.gsm_fr_decode_ps_sptr_swigregister(gsm_fr_decode_ps_sptrPtr)


def gsm_fr_decode_ps_block(*args):
    """gsm_fr_decode_ps_block(gsm_fr_decode_ps_sptr r) -> gr_block_sptr"""
    return _gsm_full_rate.gsm_fr_decode_ps_block(*args)
gsm_fr_decode_ps_sptr.block = lambda self: gsm_fr_decode_ps_block (self)
gsm_fr_decode_ps_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


def decode_ps(*args):
    """decode_ps() -> gsm_fr_decode_ps_sptr"""
    return _gsm_full_rate.decode_ps(*args)
